import os
import random
import bpy
import product_gen.generate_lamp
import rendering.setup_scene
import rendering.setup_renderer
from shapes.shape_description import _styles

def generate(shape_parameters, output_prefix, is_final=False):
    
    rendering.setup_renderer.setup_renderer(shape_parameters,
                                             is_final)
    
    rendering.setup_scene.initialize_scene(shape_parameters)
    
    # Generate models
    models = product_gen.generate_lamp.generate_models(shape_parameters)
    
    # Optimize geometries for render
    product_gen.generate_lamp.optimize_for_render(models)

    # Set up materials and textures
    style = _styles[shape_parameters["style"]]
    if "bio" not in shape_parameters["shape"]:
        colormap = {"shade": style["shade"],
                    "base": style["base"],
                    "chord": style["chord"]}
    else:
        colormap = {"shade": style["shade"]}
        
    product_gen.generate_lamp.apply_textures(colormap, models)
    
    rendering.setup_scene.setup_scene(shape_parameters)
    
    # Do rendering
    prefix = os.getcwd() + "/" + output_prefix + "/" + output_prefix
    if is_final:
        bpy.context.scene.render.filepath = prefix + "_highres.png"
        bpy.ops.render.render(write_still=True)        
    else:
        bpy.context.scene.render.filepath = prefix + ".png"
        bpy.ops.render.render(write_still=True)
        
    bpy.ops.wm.save_as_mainfile(filepath=prefix + ".blend") 
    
    return shape_parameters